@@ -8,6 +8,7 @@
 //!
 
 pub mod accounts_hash_verifier;
+pub mod ancestor_hashes_service;
 pub mod banking_stage;
 pub mod broadcast_stage;
 pub mod cache_block_meta_service;
@@ -21,6 +22,7 @@ pub mod completed_data_sets_service;
 pub mod consensus;
 pub mod cost_update_service;
 pub mod drop_bank_service;
+pub mod duplicate_repair_status;
 pub mod fetch_stage;
 pub mod fork_choice;
 pub mod gen_keys;
@@ -31,6 +33,8 @@ pub mod optimistic_confirmation_verifier;
 pub mod outstanding_requests;
 pub mod packet_hasher;
 pub mod progress_map;
+pub mod qos_service;
+pub mod repair_generic_traversal;
 pub mod repair_response;
 pub mod repair_service;
 pub mod repair_weight;
@@ -49,13 +53,14 @@ pub mod sigverify_shreds;
 pub mod sigverify_stage;
 pub mod snapshot_packager_service;
 pub mod system_monitor_service;
-pub mod test_validator;
+pub mod tower_storage;
 pub mod tpu;
 pub mod tree_diff;
 pub mod tvu;
 pub mod unfrozen_gossip_verified_vote_hashes;
 pub mod validator;
 pub mod verified_vote_packets;
+pub mod vote_simulator;
 pub mod vote_stake_tracker;
 pub mod voting_service;
 pub mod window_service;
