@@ -425,6 +425,13 @@ impl Validator {
                     accountsdb_plugin_service.get_transaction_notifier()
                 });
 
+        let block_metadata_notifier =
+            accountsdb_plugin_service
+                .as_ref()
+                .and_then(|accountsdb_plugin_service| {
+                    accountsdb_plugin_service.get_block_metadata_notifier()
+                });
+
         info!(
             "AccountsDb plugin: accounts_update_notifier: {} transaction_notifier: {}",
             accounts_update_notifier.is_some(),
@@ -828,6 +835,11 @@ impl Validator {
                     .iter()
                     .map(|s| s.try_clone().expect("Failed to clone TVU forwards Sockets"))
                     .collect(),
+                ancestor_hashes_requests: node
+                    .sockets
+                    .ancestor_hashes_requests
+                    .try_clone()
+                    .expect("Failed to clone ancestor_hashes_requests socket"),
             },
             blockstore.clone(),
             ledger_signal_receiver,
@@ -871,6 +883,7 @@ impl Validator {
             &cost_model,
             accounts_package_channel,
             last_full_snapshot_slot,
+            block_metadata_notifier,
         );
 
         let tpu = Tpu::new(
